@@ -13,8 +13,8 @@ glpkpi = Extension('_glpkpi', libraries = ['glpk'],
 extmods = [glpkpi];
 
 setup (name = 'glpk', 
-    description = 'Python-glpk package',
-    version = '0.3.43', 
+    description = 'python-glpk package',
+    version = '0.4.52', 
     long_description = """
 Python-glpk is a free software package providing bindings in the
 Python programming language for the GLPK linear and integer
